@@ -4,6 +4,7 @@ from django.core.urlresolvers import reverse
 from netcash.models import NetcashGateway, NetcashOrder
 from netcash.forms import NetcashForm
 import netcash.signals
+from django.contrib.auth.models import User
 
 class NetcashTest(TestCase):
 
@@ -28,6 +29,8 @@ class NetcashTest(TestCase):
         self.assertEqual(NetcashOrder.objects.count(), 0)
 
     def test_data_request(self):
+        user = User.objects.create_user('kmike', 'example@example.com')
+
         # signal handler
         def data_handler(sender, order, **kwargs):
             data_handler.called = True
@@ -41,9 +44,10 @@ class NetcashTest(TestCase):
         form = NetcashForm(initial={
             'p3': 'description',
             'p4': 100,
-        })
+        }, user=user)
         reference = str(form.order.pk)
         self.assertEqual(form.order.trusted, None)
+        self.assertEqual(form.initial['m_9'], user.email)
 
         self.assertFalse(data_handler.called)
 
@@ -72,6 +76,7 @@ class NetcashTest(TestCase):
         self.assertEqual(order.gateway, self.gateway)
         self.assertEqual(order.request_ip, '127.0.0.1')
         self.assertEqual(order.trusted, True)
+        self.assertEqual(order.user, user)
 
         self.assertTrue(data_handler.called)
         self.assertEqual(data_handler.order, order)
