@@ -3,7 +3,7 @@ from django.conf.urls.defaults import *
 
 urlpatterns = patterns('netcash.views',
     url(
-          r'^data/(?P<secret>.+)$',
+          r'^data/(?P<secret>.+)/$',
           'data_handler',
           name='netcash_data'
     ),
